summaryrefslogtreecommitdiffstats
path: root/Lib/os.py
diff options
context:
space:
mode:
authorGuido van Rossum <guido@python.org>1993-12-29 15:33:08 (GMT)
committerGuido van Rossum <guido@python.org>1993-12-29 15:33:08 (GMT)
commitdd8cb446e19cb24131227bd66aa690b34e64a75a (patch)
tree7e944159562f197b8288ae0dacc78343db173d0f /Lib/os.py
parent424e4da9f38fe8281cae370936ff266bcbeb0804 (diff)
downloadcpython-dd8cb446e19cb24131227bd66aa690b34e64a75a.zip
cpython-dd8cb446e19cb24131227bd66aa690b34e64a75a.tar.gz
cpython-dd8cb446e19cb24131227bd66aa690b34e64a75a.tar.bz2
Some minute changes.
Diffstat (limited to 'Lib/os.py')
-rw-r--r--Lib/os.py30
1 files changed, 20 insertions, 10 deletions
diff --git a/Lib/os.py b/Lib/os.py
index 7322fa5..bb90f2e 100644
--- a/Lib/os.py
+++ b/Lib/os.py
@@ -1,4 +1,4 @@
# os.py -- either mac or posix depending on what system we're on.
# This exports:
# - all functions from either posix or mac, e.g., os.unlink, os.stat, etc.
@@ -14,7 +14,7 @@
# and opendir), and leave all pathname manipulation to os.path
# (e.g., split and join).
-# XXX This will need to distinguish between real posix and MS-DOS emulation
+# XXX This is incorrect if the import *path fails...
try:
from posix import *
@@ -30,14 +30,24 @@ try:
path = posixpath
del posixpath
except ImportError:
- from mac import *
- name = 'mac'
- curdir = ':'
- pardir = '::'
- sep = ':'
- import macpath
- path = macpath
- del macpath
+ try:
+ from mac import *
+ name = 'mac'
+ curdir = ':'
+ pardir = '::'
+ sep = ':'
+ import macpath
+ path = macpath
+ del macpath
+ except ImportError:
+ from dos import *
+ name = 'dos'
+ curdir = '.' # XXX doesn't always work
+ pardir = '..' # XXX doesn't always work
+ sep = '/' # XXX or '\\' ???
+ import dospath
+ path = dospath
+ del dospath
def execl(file, *args):
execv(file, args)
@@ -1,4 +1,4 @@
-# os.py -- either mac or posix depending on what system we're on.
+# os.py -- either mac, dos or posix depending on what system we're on.
# This exports:
# - all functions from either posix or mac, e.g., os.unlink, os.stat, etc.